pub fn from_url(url: &str) -> Result<Box<dyn RemotePackage>, PkgError>
Create a RemotePackage from a URL.

Uses a blocking tokio client to download the remote package - if using this in an async environment, surround this with tokio::spawn_blocking.