Function remote_package::from_url
source · [−]pub fn from_url(url: &str) -> Result<Box<dyn RemotePackage>, PkgError>Expand description
Create a RemotePackage from a URL.
Uses a blocking tokio client to download the remote package - if using this in an async environment, surround this with tokio::spawn_blocking.